/*
 * Licensed Materials - Property of IBM
 * IBM Sterling Field Sales
 * (C) Copyright IBM Corp. 2009, 2012 All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */
 
Ext.namespace('sc.sfs.common.paymentinformation');

sc.sfs.common.paymentinformation.paymentmethodpanel = function(config) {
	if(config && config.enablePADSS){
		//each frame ID needs to be unique because when the popup closes the frame ID is not released meaning all subsequent 
		//times the frame lods the frame cannot be uniquely identified.
		var counter=sc.app.common.core.data.CacheDataManager.getData("padssCounter");
		if(counter){
			counter=counter+1;
		}else{
		counter=1;	
		}
		sc.app.common.core.data.CacheDataManager.setData("padssCounter",counter);
		this.iframeID = "padssIframe"+new Date().getTime()+"index"+ counter;
	}
    sc.sfs.common.paymentinformation.paymentmethodpanel.superclass.constructor.call(this, config);
}
Ext.extend(sc.sfs.common.paymentinformation.paymentmethodpanel, sc.plat.ui.ExtensibleScreen, {
    className: 'sc.sfs.common.paymentinformation.paymentmethodpanel',
    getUIConfig: sc.sfs.common.paymentinformation.paymentmethodpanelUIConfig,
    namespaces: {
        target: ['targetPaymentMethod'],
        source: ['paymentMethod']
    },
    namespacesDesc: {
        targetDesc: ['Used to get the changes made to this payment method when save is selected.'],
		sourceDesc: ['Used to populate the fields when an existing payment method is being modified.']
    },
    /* This method should be overridden by the extending class */
    disableComponents: function(){
    	//By default disable the panel
    	this.disable();
    },
    
    /* This method should be overridden by the extending class */
    enableComponents: function(){
    	//By default enable the panel
    	this.enable();
    },

	PaymentGroupType:"",
	PaymentType:"",
	iframeID:null,

	ssdcsDataType:"",
	ssdcsDisplayValue:"",
	ssdcsToken:"",
	ssdcsCssUrl: Ext.isIE ? location.protocol + "//" + location.host + "/" + sc.plat.info.Application.getApplicationContext() + "/sfs/resources/default/css/sfs-pa-dss-ie.css"
							  : location.protocol + "//" + location.host + "/"	+ sc.plat.info.Application.getApplicationContext() + "/sfs/resources/default/css/sfs-pa-dss.css",

	loadData:function(config){
		//This method can be overridden by the extending panels to set additional models etc.
	},

	loadPaymentMethod:function(config){
		this.setModel(config, "paymentMethod");
		if(this.iframeID){
			this.requestPADSSPanel();
		}
	},


	getPaymentMethod:function(){
		var hasError = this.hasError();
		if(hasError){
			var componentsInError = this.findAllComponentsInError();
			var errorObj ={};
			errorObj.em=componentsInError[0].blankText;
			//now call the handleError method
			sc.plat.RequestUtils.handleErrors(errorObj);
			componentsInError[0].focus();
			return;
		}
		if(this.iframeID){
			this.getTokenForCC();
		}else{
			this.ownerScr.returnPaymentMethodAndClosePopup(this.getTargetModel("targetPaymentMethod")[0]);
		}
	},

	/* Start PA-DSS Logic */
	requestPADSSPanel : function(){
//		var counter=sc.app.common.core.data.CacheDataManager.getData("padssCounter");
//		if(counter){
//			counter=counter+1;
//		}else{
//		counter=1;	
//		}
//		sc.app.common.core.data.CacheDataManager.setData("padssCounter",counter);
		this.find("sciId", "pnlPADSS")[0].body.createChild(
			{
				tag: 'IFRAME', 
				'class': 'sfs-padss-iframe',
				frameborder: "0",
				name: this.iframeID,
				id: this.iframeID,
				hidefocus:"on",
				unselectable:"on",
				scrolling: 'no'
			}
		);

		var cnfg = {
			ReturnURL : location.protocol + "//" + location.host + "/"
						+ sc.plat.info.Application.getApplicationContext()
						+ "/sfs/common/paymentinformation/padss.do",
			ssdcsDataType : this.ssdcsDataType,
			ssdcsDisplayValue: this.ssdcsDisplayValue,
			ssdcsCssUrl: this.ssdcsCssUrl,
			ssdcsToken: this.ssdcsToken
		};
		
		sc.plat.FormUtils.request({
			url : location.protocol + "//" + location.host + "/" 
					+ sc.plat.info.Application.getApplicationContext()
					+ "/sfs/common/getaccesstoken.do",
			method : 'POST',
			params : cnfg,
			target : this.iframeID
		});
    },

	isAlreadyAdded:function(addedPaymentMethodList, modifiedData){
		var addedPaymentMethods = sc.plat.DataUtils.extractData(addedPaymentMethodList, "PaymentMethods.PaymentMethod");

		if(addedPaymentMethods){
			for(var i=0 ; i<addedPaymentMethods.length ; i++){
				var currentMethod = addedPaymentMethods[i];
				if(currentMethod.PaymentType == this.PaymentType && currentMethod.RowNo != modifiedData.PaymentMethod.RowNo){
					if(this.isDuplicate(currentMethod)){
						return true;
					}
				}
			}
		}
		return false;
	},

	isDuplicate:function(paymentMethod){
		//Needs to be overridden by each extending class to determine if this payment method is equal to a payment that is already on the order.
	},
	success: function (  ) {
		var ownerScr = window.PadssubmitOwnerScr;
		var framename = ownerScr.iframeID;
		//Get iframe
		var padssIframe = window.frames[framename];
		var form = padssIframe.document.ssdcs;
		theDiv = document.getElementById(framename);
		//if(theDiv){
		//	padssIframe.document.body.innerHTML = response.responseText;
		//}
		//if form.ssdcsResultCode succeeds
		//		get the credit card type, display, token
		var resultCode = padssIframe.document.ssdcs.ssdcsResultCode.value;
		if(resultCode == "SUCCESS"){
			var displayValue = padssIframe.document.ssdcs.ssdcsDisplayValue.value;
			var token = padssIframe.document.ssdcs.ssdcsToken.value;
			ownerScr.padssFormSubmitSuccess(null, displayValue, token, resultCode);
			/*the response from the padss server which includes the ResultCode, tokenized value, display value
			is attached to the frame. callbackMethod can perform additional validations before form-submit by reading the elements in the
			frame attached from the response from the padss server. Also, add additional error messages in the UI, if the tokenization 
			failed based on the ResultCode and ResultDescription.*/
		}else{
			//if failed
			//		get reason code
			//		if reason code timeout
			//			get new token
			//			resubmit
			//		else
			//			display error
			var failureReason = padssIframe.document.ssdcs.ssdcsFailReason.value;
			if(resultCode === "FAIL"){
				if(failureReason === "INVALID_SESSION"){
					var errorObj ={'em':sc.plat.bundle["b_PADSS_INVALID_SESSION"]};
					sc.plat.RequestUtils.handleErrors(errorObj);
					ownerScr.reloadIframeWithNewAccessToken();
				}else if(failureReason === "INVALID_DATA"){
					var resultDescription = padssIframe.document.ssdcs.ssdcsResultDescription.value;
					if(resultDescription=="ssdcsDataToTokenize"){
						var errorObj ={'em':sc.plat.bundle["b_PADSS_FAIL_"+failureReason+"_"+ownerScr.PaymentType]};
						sc.plat.RequestUtils.handleErrors(errorObj);
					}else{
						var errorObj ={'em':sc.plat.bundle["b_PADSS_FAIL_OTHER"]};
						sc.plat.RequestUtils.handleErrors(errorObj);
					}
				}else{
					var errorObj ={'em':sc.plat.bundle["b_PADSS_FAIL_"+failureReason]};
					sc.plat.RequestUtils.handleErrors(errorObj);
				}
			}
		}
	},
	failure: function ( response, request ) {
		var errorObj ={'em':"SOME ERROR NEEDS TO GO HERE"};
		sc.plat.RequestUtils.handleErrors(errorObj);
		return;
	},
	getTokenForCC: function() {
		var framename = this.iframeID;
		//Get iframe
		var padssIframe = window.frames[framename];
		var form = padssIframe.document.ssdcs;
		var ownerScr = this;
		
		var submitRequired = padssIframe.checkSubmit(form);
		
		//if(true) submit form in iframe form.submit Ext.getCmp("id", "ssdcs").form.submit();
		if(submitRequired){
			window.PadssubmitOwnerScr = this;
			padssIframe.submitPAN(this.success, this.failure);
		}else{
			var state = padssIframe.document.ssdcs.ssdcsResultCode.value;
			if(state === "FAIL" || (state === "INITIAL" && padssIframe.document.ssdcs.ssdcsToken.value === "")){
				var errorObj="";
				if(ownerScr.PaymentType==="CREDIT_CARD"){
				errorObj ={'em':sc.app.common.util.MessagesUtil.getRequiredFieldText("b_CreditCardNo")};
				}else if(ownerScr.PaymentType==="SVC"){
				errorObj ={'em':sc.app.common.util.MessagesUtil.getRequiredFieldText("b_SVCCardNo")};
				}
				//now call the handleError method
				sc.plat.RequestUtils.handleErrors(errorObj);
				//TODO: set focus on the field
				//TODO: mark field in error
				//TODO: set error tool tip
				return;
			}else{
				var displayValue = padssIframe.document.ssdcs.ssdcsDisplayValue.value;
				var token = padssIframe.document.ssdcs.ssdcsToken.value;
				ownerScr.padssFormSubmitSuccess(submitRequired, displayValue, token, state);
			}
		}
	},

	padssFormSubmitSuccess: function(submitRequired, displayValue, token, state){ 
		//Extending panel should implement this 
	},

	reloadIframeWithNewAccessToken:function(){
		var ownerScr = this;
		sc.app.common.util.DataAjaxUtils.request({
			action : "getNewAccessToken",
			actionNS : "/sfs/common",
			success : function(res, opt){
				window.frames[ownerScr.iframeID].document.ssdcs.ssdcsAuthenticationToken.value = res.responseText;
			},
			failure:function(res, opt){
				var errorObj ={'em':"SOME ERROR NEEDS TO GO HERE TOO"};
				sc.plat.RequestUtils.handleErrors(errorObj);
				return;
			},
			params:{getAccessToken_input:Ext.encode({"AccessToken":{"UserId":sc.plat.Userprefs.getUserId()}})},
			scope : this
		});
	}

	/* End PA-DSS Stuff Logic*/

});
Ext.reg('paymentMethodPanel', sc.sfs.common.paymentinformation.paymentmethodpanel);
