/*
 * Licensed Materials - Property of IBM
 * IBM Sterling Field Sales
 * (C) Copyright IBM Corp. 2009, 2015 All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */
 
Ext.ns('sc.sfs.itembrowsing');

sc.sfs.itembrowsing.ItemDetails = function(config) {
	sc.sfs.itembrowsing.ItemDetails.superclass.constructor.call(this, config);
}
Ext.extend(sc.sfs.itembrowsing.ItemDetails, sc.plat.ui.ExtensibleScreen, {
    className: 'sc.sfs.itembrowsing.ItemDetails',
    getUIConfig: sc.sfs.itembrowsing.ItemDetailsUIConfig,
    namespaces: {
        target: ['AddToQuote'],
        source: ['ItemDetails']
    },
    
    namespacesDesc: {

    	targetDesc: ["This namespace contains the item model which is used to add selected items to the quote."],
        sourceDesc: ["This namespace contains the item details  model used to populate the screen."]


    },
    itemDetails: null,
    Currency: null,
    modHeader:null,
    selectedVariationAttributes: {},
    getCheckAvailabilityIcon: "<img src='"+Ext.BLANK_IMAGE_URL+"' class='sfs-check-availability'>",
    initializeScreen: function(itemDetailsOutput, itemDetailsInput, variationItemsList, itemPriceOutput, strTplSpecifications, strTplVariations, strTplAdditionalCharges, tabSelection){

    	if(itemDetailsOutput.ItemList.Item){
			this.itemDetails = {};
		    this.itemDetails.Item = itemDetailsOutput.ItemList.Item[0];
		}else{
			return; //TODO Display 'no item available' panel
		}
		if(itemPriceOutput.ItemPrice.LineItems.LineItem[0]){
			this.itemPrice = itemPriceOutput.ItemPrice.LineItems.LineItem[0];
		}
    	var mode=itemDetailsInput.Item.SearchMode;
    	if(!Ext.isEmpty(mode)){
    		sc.sfs.itembrowsing.ItemUtils.setItemSearchMode(mode);
    	}
    	
    	var pricingDate=itemDetailsInput.Item.PricingDate;
    	if(!Ext.isEmpty(pricingDate)){
	    	var canPricingDateBeShown=sc.sfs.itembrowsing.ItemUtils.canPricingDateBeShown(pricingDate);
	    	if(canPricingDateBeShown){
	    		//get the label to show and set the root panel to true
				var pricingDateVal="";
				var formattedDate="";
				var textMsg="";
				var pnlPricingDateInfo=this.find("sciId","pnlPricingDateInfo")[0];
				var lblPricingInfo=this.find("sciId","lblPricingDate")[0];
				if(!(pricingDate instanceof Date)){
					pricingDateVal=Date.parseDate(pricingDate,"c");
					formattedDate=pricingDateVal.dateFormat(sc.plat.Userprefs.getDateFormat());
					textMsg=String.format(sc.plat.bundle["b_ItemBrowsingDetailsDateInfo"], formattedDate);
					lblPricingInfo.setText(textMsg);
				}
				
				pnlPricingDateInfo.show();
	    	}
    	}
		this.ScreenInput = itemDetailsInput;
		if(this.ScreenInput && this.ScreenInput.Item && this.ScreenInput.Item.CustomerInformation && this.ScreenInput.Item.CustomerInformation.CustomerID){
			sc.app.common.core.data.CacheDataManager.setData("CustomerID", this.ScreenInput.Item.CustomerInformation.CustomerID);
		}else{
			sc.app.common.core.data.CacheDataManager.setData("CustomerID", "");
		}
		if(this.ScreenInput && this.ScreenInput.Item && this.ScreenInput.Item.PricingDate){
			sc.app.common.core.data.CacheDataManager.setData("PricingDate", this.ScreenInput.Item.PricingDate);
		}else{
			sc.app.common.core.data.CacheDataManager.setData("PricingDate", "");
		}
    	this.Currency = itemDetailsOutput.ItemList.Currency;
    	sc.app.common.core.data.CacheDataManager.setData("quoteCurrency", this.Currency);
		
		variationItemUtils.resetProperties();
		if(variationItemsList && variationItemsList.ItemList.Item){
			this.selectedVariationAttributes = {};
			variationItemUtils.loadItemAttributes(variationItemsList);
			this.find("sciId", "labelVariationItemsWarning")[0].setVisible(false);
		}else{
			this.find("sciId", "labelVariationItemsWarning")[0].setVisible(true);
		}
		
    	var currentScreen = this;
    	this.tplSpecifications = new Ext.XTemplate(strTplSpecifications, currentScreen.getSpecificationsTemplateConfig());
    	this.tplSpecifications.compile();
    	
    	this.tplVariations = new Ext.XTemplate(strTplVariations, currentScreen.getVaraitaionsTemplateConfig());
    	this.tplVariations.compile();
		
    	this.tplAdditionalCharges = new Ext.XTemplate(strTplAdditionalCharges, currentScreen.getAdditionalChargesTemplateConfig(this.Currency));
    	this.tplAdditionalCharges.compile();
		
    	this.updateTabs(tabSelection);
    	
    	this.setModel(this.itemDetails, "ItemDetails");
    	this.setModel(this.itemPrice, "ItemPrice");
    	this.updateUIData();
    	this.doLayout();
    	this.syncSize();
    	this.clean();
    },
    updateUIData: function(){
		this.loadItemMainImage();
    	this.setPanelTitle();
		this.updateUOM();
		this.formatLinePrice();
		this.formatUnitPrice();
		this.handleAddToQuoteButton();
		this.showMoreImages();
		this.showDataSheet();
		this.showCheckAvailability();
		this.showConfigurableItem();
		this.setStatusModification();
    },

    setStatusModification: function(){
    	
	if(this.parent && this.parent.ownerScr){
	 this.modHeader = this.parent.ownerScr.modHeader;    	
	}

	 if (this.modHeader && this.modHeader.ADD_LINE == "N")
	 {
	   var addToQuote = this.find("sciId", "btnAddoQuote")[0];
	   sc.sfs.common.util.StatusModificationUtils.disableButton(addToQuote);
		   
	 }
	
	},    

    showConfigurableItem: function(){
    	if(sc.sfs.itembrowsing.ItemUtils.isItemConfigurable(this.itemDetails.Item)){
    		this.find("sciId", "pnlConfigurableItem")[0].setVisible(true);
    		this.find("sciId", "lblConfigurableItemIcon")[0].getEl().addClass("sfs-configure");
    	}
    },
    showCheckAvailability: function(){
    	if(sc.sfs.itembrowsing.ItemUtils.isCheckAvailibilityValid(this.itemDetails.Item)){
    		var pnlCheckAvailability = this.find("sciId", "pnlCheckAvailability")[0];
    		pnlCheckAvailability.setVisible(true);
    		
//    		this.find("sciId", "lblCheckAvailabilityIcon")[0].getEl().addClass("sfs-check-availability");
    	}
    },
    showMoreImages: function(){
    	var moreImages = this.getAssetsOfType(this.itemDetails, "ITEM_IMAGE_LRG_1");
    	if(moreImages.length > 0){
    		var pnlMoreImages = this.find("sciId", "pnlMoreImages")[0];
    		pnlMoreImages.setVisible(true);
    	}
    },
    showDataSheet: function(){
    	var dataSheets = this.getAssetsOfType(this.itemDetails, "ITEM_DATA_SHEET");
    	if(dataSheets.length > 0){
    		var lnkDataSheet = this.find("sciId", "lnkDataSheet")[0];
    		lnkDataSheet.setVisible(true); 		
    	}
    },
    setPanelTitle: function(){
    	var pnlContent = this.find("sciId","pnlContent")[0];
    	pnlContent.setTitle(sc.sfs.itembrowsing.ItemUtils.getFormattedItemDisplay(this.itemDetails.Item));
    },
    updateUOM:function(){
    	var dfUOM = this.find("sciId", "dfUOM")[0];
    	var uomDesc = sc.sfs.core.cache.uom.uomManager.getUomDescriptionFromUom(this.itemDetails.Item.UnitOfMeasure);
    	if(!uomDesc){
    		uomDesc = this.itemDetails.Item.UnitOfMeasure;
    	}
    	dfUOM.setValue(uomDesc);
    },
    formatLinePrice: function(){
    	var lblLinePrice = this.find("sciId", "lblLinePrice")[0];
    	var formattedPrice = sc.sfs.itembrowsing.ItemUtils.getFormattedUnitPrice(this.itemDetails.Item.ComputedPrice, this.itemDetails.Item.PrimaryInformation, this.Currency);
    	lblLinePrice.setValue(formattedPrice);
    },
    formatUnitPrice: function(){
    	var dfUnitPrice = this.find("sciId", "dfUnitPrice")[0];
    	var formattedPrice = sc.app.common.util.FormatterUtils.getFormattedCurrency(this.itemPrice.UnitPrice, this.Currency);
    	dfUnitPrice.setValue(formattedPrice);
    },
    handleAddToQuoteButton: function(){
    	if(sc.sfs.itembrowsing.ItemUtils.getItemSearchMode() === sc.sfs.itembrowsing.ItemUtils.MODE_ADD){
	    	if(sc.sfs.itembrowsing.ItemUtils.isAddToQuoteValid(this.itemDetails.Item)){
				var pnlAddToQuote = this.find("sciId", "btnAddoQuote")[0];	
				pnlAddToQuote.setVisible(true);
			}
    	}
    },
    loadItemMainImage:function(){
    	var shortDescription = this.itemDetails.Item.PrimaryInformation.ShortDescription;
    	var imagePnl = this.find("sciId", "pnlItemMainImage")[0];
		var el = imagePnl.getEl().first().first();
		if(el.first()){
			el.first().remove();	
		}
		var assetList = this.getAssetsOfType(this.itemDetails, "ITEM_IMAGE_1");
		var url = Ext.BLANK_IMAGE_URL;
		if(assetList[0]){
			var location = assetList[0].ContentLocation;
			var fileName = assetList[0].ContentID;
			if(location && fileName){
				url = location+"/"+fileName; 
			}
		}
		Ext.DomHelper.insertHtml("afterBegin",el.dom,"<img src='"+url+"' width='215' height='200' align='center' alt='"+shortDescription+"'/>" ); //onError='this.src=\""+Ext.BLANK_IMAGE_URL+"\"'

    },
    
    getAssetsOfType: function(itemDetails, assetType){
    	var assetList = [];
    	if(itemDetails.Item.AssetList && itemDetails.Item.AssetList.Asset){
    		var assets = itemDetails.Item.AssetList.Asset;
	    	for(var i=0; i<assets.length; i++){
	    		var asset = assets[i];
	    		if(asset.Type === assetType){
	    			assetList.push(asset);
	    		}
	    	}
    	}
    	return assetList;
    },
    
    getSpecificationsTemplateConfig: function(){
    	return {
    		getValue: function(data, jsonPath){
   				return sc.plat.DataUtils.extractData(data, jsonPath);
   			},
   			isRightHandSideColumn: function(index){
   				if(index%2 === 0){
   					return true;
   				}else{
   					return false;
   				}
   			},
   			isValidPath: function(data, jsonPath){
   				if(data && sc.plat.DataUtils.extractData(data, jsonPath)){
   					return true;
   				}else{
   					return false;
   				}
   			},
   			hasAssignedValueList: function(assignedValueList){
   				if(assignedValueList.AssignedValue){
   					return true;
   				}else{
   					return false;
   				}
   			},
   			getAttributeValue: function(attribute, assignedValue){
   				var dataType = "";
   				if(attribute){
   					dataType = attribute.DataType;
   				}
   				if(dataType === "INTEGER"){
   					return assignedValue.IntegerValue;
   				}else if(dataType === "DECIMAL"){
   					return assignedValue.DoubleValue;
   				}else if(dataType === "BOOLEAN"){
   					var value = assignedValue.Value;
   					if(value === "Y"){
   						return sc.plat.bundle["b_Yes"];
   					}else if(value === "N"){
   						return sc.plat.bundle["b_No"];
   					}
   					return value; 
   				}else{
   					return assignedValue.Value; 
   				}
   			}
    	};
    },
    
    getVaraitaionsTemplateConfig: function(){
    	return {
    		isAddMode: function(){
    			return sc.sfs.itembrowsing.ItemUtils.getItemSearchMode() === sc.sfs.itembrowsing.ItemUtils.MODE_ADD;
    		},
    		isImageAvailable: function(attributeValueImage){
    			return Ext.isEmpty(attributeValueImage)? false : true;
    		}
    	};
    },
    
    getAdditionalChargesTemplateConfig: function(itemPriceCurrency){
        return {
            currency: itemPriceCurrency,
            isUpfrontCharge: function(isPriceTypeForInformationOnly){
                return "N" == isPriceTypeForInformationOnly;
            },
            getFormattedPrice: function(multiPrice){
                return sc.app.common.util.FormatterUtils.getFormattedCurrency(multiPrice, this.currency);
            },
            isRecurring: function(recurringType){
                return !Ext.isEmpty(recurringType);
            },
            readFromBundle: function(key){
                var value = sc.plat.bundle[key];
                if(Ext.isEmpty(value)){
                    value = key;
                }
                return value;
            }
    	};
    },
	
    updateTabs: function(tabSelection){
    	var tabPanel = this.find("sciId", "tabPnlMoreDetails")[0];
    	if(tabSelection){
    		tabPanel.setActiveTab(tabSelection);
    	}
    	
    	this.updateAssociatedItems();
    	
    	this.updateSpecifications();
		
    	this.updateAdditionalCharges();
    	
    	
    	//Cross-Sell Tab
//    	var crossSells = this.getAssociationList("CrossSell");
//    	var pnlCrossSell = this.find("sciId", "pnlCrossSell")[0];
//    	if(crossSells){
//    		pnlCrossSell.setModelForComponents(crossSells);
//    	}else{
//    		tabPanel.hideTabStripItem(pnlCrossSell);
//    	}
    	//End - Cross-Sell Tab
    	
    	//Up-Sell Tab
//    	var upSells = this.getAssociationList("UpSell");
//    	var pnlUpSell = this.find("sciId", "pnlUpSell")[0];
//    	if(upSells){
//    		pnlUpSell.setModelForComponents(upSells);
//    	}else{
//    		tabPanel.hideTabStripItem(pnlUpSell);
//    	}
    	//End - Up-Sell Tab
    	
    	//Components Tab
    	var pnlComponents = this.find("sciId", "pnlComponents")[0];
    	if(this.canShowComponents()){
    		var components = this.getComponentItems();
    		if(components){
    			pnlComponents.setModelForComponents(components);
    		}
    	}else{
    		tabPanel.hideTabStripItem(pnlComponents);
    	}
    	//End - Components Tab
    	
    	//Variations Tab
    	var pnlVaraitions = this.find("sciId", "pnlVariationItemsContainer")[0];
    	if(this.itemDetails.Item.PrimaryInformation 
    		&& this.itemDetails.Item.PrimaryInformation.IsModelItem == "Y"){
    	}else{
    		tabPanel.hideTabStripItem(pnlVaraitions);
    	}
    	//End - Variations Tab
    },
    updateSpecifications: function(){
    	var hasAttributes = false; 
    	var itemAttrGroupTypeList = this.itemDetails.Item.ItemAttributeGroupTypeList;
    	if(itemAttrGroupTypeList){
    		var itemAttrGroupType = itemAttrGroupTypeList.ItemAttributeGroupType;
    		if(itemAttrGroupType && Ext.isArray(itemAttrGroupType)){
    			for(var i=0; i<itemAttrGroupType.length; i++ ){
    				var itemAttrGroupList = itemAttrGroupType[i].ItemAttributeGroupList;
    				if(itemAttrGroupList){
    					var itemAttrGroup = itemAttrGroupList.ItemAttributeGroup;
    					if(itemAttrGroup && Ext.isArray(itemAttrGroup)){
    						for(var j=0; j<itemAttrGroup.length; j++){
    							if(itemAttrGroup[j].ItemAttributeGroupID == "Dummy"){
    								itemAttrGroup.remove(itemAttrGroup[j]);
    								continue;
    							}
    							var itemAttrList = itemAttrGroup[j].ItemAttributeList;
    							if(itemAttrList){
    								var itemAttr = itemAttrList.ItemAttribute;
    								if(itemAttr && Ext.isArray(itemAttr) && itemAttr.length > 0){
			    						hasAttributes = true;
    								}
    							}
    						}
    					}
    				}
    			}
    		}
    	}
    	
    	if(!hasAttributes){
    		var specificationsTab = this.find("sciId", "pnlSpecificationsContainer")[0];
    		specificationsTab.disable();
    	}
    },
	updateAdditionalCharges: function(){
    	var hasAdditionalCharges = false; 
    	if(this.itemPrice.AdditionalLinePrices && this.itemPrice.AdditionalLinePrices.AdditionalLinePrice){
            hasAdditionalCharges = true;
        }
    	
    	if(!hasAdditionalCharges){
            var tabPanel = this.find("sciId", "tabPnlMoreDetails")[0];
    		var additionalChargesTab = this.find("sciId", "pnlAdditionalChargesContainer")[0];
            tabPanel.hideTabStripItem(additionalChargesTab);
            
    	}
    },
    updateAssociatedItems: function(){
    	if(this.itemDetails.Item.AssociationTypeList && this.itemDetails.Item.AssociationTypeList.AssociationType
    		&& Ext.isArray(this.itemDetails.Item.AssociationTypeList.AssociationType)){
    		
    		var assocTabs = [];	
    		var associationTypes = this.itemDetails.Item.AssociationTypeList.AssociationType;
    		for(var i=0; i<associationTypes.length; i++){
    			var associationType = associationTypes[i];
    			if(associationType.AssociationList && associationType.AssociationList.Association &&
    				associationType.AssociationList.Association.length > 0){
    				
    				var mode = "";
    				if(sc.sfs.itembrowsing.ItemUtils.getItemSearchMode() == sc.sfs.itembrowsing.ItemUtils.MODE_ADD){
						mode = sc.sfs.itembrowsing.ItemUtils.MODE_ADD;
					}else{
						mode = sc.sfs.itembrowsing.ItemUtils.MODE_VIEW;
					}
					
	    			var associationItem = new sc.sfs.itembrowsing.AssociatedItem({"mode": mode, "ViewDetails": true});
	    			var title = associationType.CodeShortDescription;
	    			if(!title){
	    				title = associationType.Type;
	    			}
	    			associationItem.title = title;
	    			associationItem.setModelForAssociations(associationType);
	    			assocTabs.push(associationItem);
    			}
    		}
    		if(Ext.isArray(assocTabs) && assocTabs.length > 0){
    			var tabPanel = this.find("sciId", "tabPnlMoreDetails")[0];
    			tabPanel.add(assocTabs);
    		}
    	}
    },
    canShowComponents: function(){
    	var primaryInformation = this.itemDetails.Item.PrimaryInformation;
    	if(primaryInformation.KitCode === "BUNDLE" || primaryInformation.KitCode === "PK" 
    		|| primaryInformation.KitCode === "LK"){
    		if(!primaryInformation.IsConfigurable || primaryInformation.IsConfigurable == "N"){
    			return true;
    		}else if(primaryInformation.IsConfigurable == "Y" 
    			&& primaryInformation.IsPreConfigured == "Y"
    			&& primaryInformation.ConfigurationKey){
    			return true;
    		}
    	}
    	return false;
    },
    getComponentItems: function(){
    	if(this.itemDetails.Item.Components && this.itemDetails.Item.Components.Component){
    		var componentsModel = {};
    		componentsModel.Components = this.itemDetails.Item.Components;
    		return componentsModel;
    	}
    	return null;
    },
    
    getAssociationList: function(assocType){
    	if(this.itemDetails.Item.AssociationTypeList && this.itemDetails.Item.AssociationTypeList.AssociationType){
	    	var associationTypes = this.itemDetails.Item.AssociationTypeList.AssociationType;
	    	for(var i=0; i<associationTypes.length; i++){
	    		var associationType = associationTypes[i];
	    		if(associationType.Type === assocType){
	    			if(associationType.AssociationList && associationType.AssociationList.Association &&
	    				associationType.AssociationList.Association.length > 0){
	    				return associationType;
	    			}
	    		}
	    	}
    	}
    	return null;
    },	
    
    onTabSelection: function(tabPanel, activeTab){
    	if(activeTab["sciId"] === "pnlSpecificationsContainer"){
    		if(!activeTab["isSpecsLoaded"]){
	    		var pnlSpecifications = this.find("sciId", "pnlSpecifications")[0];
	    		this.tplSpecifications.overwrite(pnlSpecifications.getEl(), this.itemDetails);
	    		activeTab["isSpecsLoaded"] = true;
    		}
    	}else if(activeTab["sciId"] === "pnlVariationItemsContainer"){
    		if(!activeTab["isVariationsLoaded"]){
	    		var pnlVaraitions = this.find("sciId", "pnlVariationItems")[0];
	    		var attributeInfo = variationItemUtils.getAttributeInfo();
	    		pnlVaraitions.getEl().on("click", this.variationsTabHandler, this, this.eventOptions());
	    		this.tplVariations.overwrite(pnlVaraitions.getEl(), attributeInfo);
	    		activeTab["isVariationsLoaded"] = true;
    		}
    	}else if(activeTab["sciId"] === "associateditem"){
    		if(sc.sfs.itembrowsing.ItemUtils.getItemSearchMode() === sc.sfs.itembrowsing.ItemUtils.MODE_ADD){
    			var pnlAssociatedItem = activeTab.find("sciId", "pnlassociateditem")[0];
    			var btnAddToQuote = sc.app.common.util.PlatUtils.getTopToolBarItemBySciId(pnlAssociatedItem, "btnAssocItemAddToQuote");
    			btnAddToQuote.setVisible(true);
    		}
    	}else if(activeTab["sciId"] === "pnlAdditionalChargesContainer"){
    		if(!activeTab["isAddtnlChrgsLoaded"]){
	    		var pnlAdditionalCharges = this.find("sciId", "pnlAdditionalCharges")[0];
	    		this.tplAdditionalCharges.overwrite(pnlAdditionalCharges.getEl(), this.itemPrice);
	    		activeTab["isAddtnlChrgsLoaded"] = true;
    		}
    	}
    	
    	sc.sfs.util.containerUtil.refreshContainer();
    	this.doLayout();
    	this.syncSize();
    	
    },
    
    openItemDetails: function(tempItem){
    	if(Ext.type(tempItem) == "string"){
    		tempItem = Ext.decode(tempItem);
    	}
    	var itemObj = {};
    	itemObj.ItemKey = tempItem.ItemKey;
    	if(this.ScreenInput && this.ScreenInput.Item){
    		if(this.ScreenInput.Item.CustomerInformation && this.ScreenInput.Item.CustomerInformation.CustomerID){
    			if(!itemObj.CustomerInformation){
    				itemObj.CustomerInformation = {};
    			}
				itemObj.CustomerInformation.CustomerID = this.ScreenInput.Item.CustomerInformation.CustomerID;
    		}
    		if(this.ScreenInput.Item.Currency){
    			itemObj.Currency = this.ScreenInput.Item.Currency;
    		}
    		if(this.ScreenInput.Item.PricingDate){
    			itemObj.PricingDate = this.ScreenInput.Item.PricingDate;
    		}
    	}
		var itemPriceObj = null;
		if(itemObj.Currency && tempItem.ItemID) {
			itemPriceObj = {};
			itemPriceObj.ItemPrice = {};
			itemPriceObj.ItemPrice.Currency = itemObj.Currency;
			itemPriceObj.ItemPrice.PricingDate = itemObj.PricingDate;
			if(itemObj.CustomerInformation){
				itemPriceObj.ItemPrice.CustomerID = itemObj.CustomerInformation.CustomerID;
			}
			itemPriceObj.ItemPrice.LineItems = {};
			itemPriceObj.ItemPrice.LineItems.LineItem = {};
			itemPriceObj.ItemPrice.LineItems.LineItem.ItemID = tempItem.ItemID;
			itemPriceObj.ItemPrice.LineItems.LineItem.Quantity = 1;
			itemPriceObj.ItemPrice.LineItems.LineItem.UnitOfMeasure = tempItem.UnitOfMeasure;
		} 
    	sc.sfs.itembrowsing.ItemUtils.openItemDetails(itemObj, this, this.showUI, false, itemPriceObj);
    },
    
    showUI: function(response, options){
    	eval(response.responseText);
    },
    
    openItemAvailability: function(){
    	var itemElement=this.itemDetails.Item;  
    	var inputNS = {};
		inputNS.Item = {};
		inputNS.Item.ItemID = itemElement.ItemID;
		inputNS.Item.UnitOfMeasure = itemElement.UnitOfMeasure;
		inputNS.Item.Quantity = itemElement.Quantity ? itemElement.Quantity : "";
		inputNS.Item.IsItemSuperseded = itemElement.IsItemSuperseded;
		inputNS.Item.ItemKey = itemElement.ItemKey;
		inputNS.Item.Availability = itemElement.Availability;		
		inputNS.Item.PrimaryInformation = {}; 
		inputNS.Item.PrimaryInformation.DefaultProductClass = itemElement.PrimaryInformation.DefaultProductClass; 
		inputNS.Item.PrimaryInformation.MinOrderQuantity = itemElement.PrimaryInformation.MinOrderQuantity;
		inputNS.Item.PrimaryInformation.ShortDescription = itemElement.PrimaryInformation.ShortDescription; 
    	sc.app.common.util.LoadEntityUtils.loadPopupWithClose({
			scope: this,
			parentScr: this,
			field: this,
			params: {ItemDetails:Ext.encode(inputNS)}, 
			entity: "ItemAvailabilityAction"
		});
    },
    
    openMoreImages: function(){
    	sc.app.common.util.LoadEntityUtils.loadPopupWithClose({
			scope: this,
			parentScr: this,
			field: this,
			params: {MoreImages:Ext.encode(this.getAssetsOfType(this.itemDetails, "ITEM_IMAGE_LRG_1"))},
			entity: "ItemMoreImagesPopupAction"
		});
    },
    openMoreDetails: function(){
    	var datasheets = this.getAssetsOfType(this.itemDetails, "ITEM_DATA_SHEET");
    	if(datasheets.length > 0){
    		var location = datasheets[0].ContentLocation;
			var fileName = datasheets[0].ContentID;
			if(location && fileName){
				var win = window.open("about:blank","ItemDetails","height=700,width=1020,left=0,top=0,status=no,toolbar=no,menubar=no,location=no,resizable=yes,scrollbars=yes");
				sc.plat.FormUtils.request({
				url : locatlocation+"/"+fileNameion,
				method : 'POST',
				target : 'ItemDetails'
				});
	    		win.focus();
			}
    	}
    },
    itemAddToQuote: function(){
    	sc.sfs.itembrowsing.ItemUtils.addToQuoteItems(this.itemDetails.Item);
    },
    
    upSellAddToQuote: function(){
//    	var pnlUpsell = this.find("sciId", "pnlUpSell")[0];
//    	var grid = pnlUpsell.getRelatedItemsGrid();
//    	this.addSelectedItemsToQuote(grid);
    },
    
    crossSellAddToQuote: function(){
//    	var pnlCrossSell = this.find("sciId", "pnlCrossSell")[0];
//    	var grid = pnlCrossSell.getRelatedItemsGrid();
//    	this.addSelectedItemsToQuote(grid);
    },
    
    addSelectedItemsToQuote: function(grid){
    	var items = [];
    	var selectdRecords = grid.getSelectionModel().getSelections();
    	for(var i=0; i<selectdRecords.length; i++){
    		var record = selectdRecords[i];
    		var json = record.json;
    		items.push(json.Item);
    	}
    	sc.sfs.itembrowsing.ItemUtils.addToQuoteItems(items);
    },
    
    
    getPopupData: function(){
    	return sc.sfs.itembrowsing.ItemUtils.getAddToQuoteItems();
    },
    
     eventOptions: function(){
    	return {
    		stopEvent: true,
    		stopPropagation: true,
    		scope: this
    	};
    },
    
    variationsTabHandler: function(eventObject, target, options){
		if(target){
			if(target.id === "lnkSelectedVariationItem"){
			 	options.scope.openItemDetails(sc.sfs.itembrowsing.ItemUtils.getDOMAttribute(target, "iteminfo"));
			 	return true;
			}else if((target.nodeName.toLowerCase() === "a" || target.nodeName.toLowerCase() === "img" || target.nodeName.toLowerCase() === "span") 
		 			&& sc.sfs.itembrowsing.ItemUtils.hasDOMAttribute(target, "attributeid")){
		 		var targetEl = Ext.get(target);
		 		var currentAttributeId = sc.sfs.itembrowsing.ItemUtils.getDOMAttribute(target, "attributeid");
		 		var currentAttributeValue = sc.sfs.itembrowsing.ItemUtils.getDOMAttribute(target, "attributevalue");
		 		if(currentAttributeValue === sc.plat.bundle["b_None"]){
		 			currentAttributeValue="";
				}
		 		
		 		var restartSelection = variationItemUtils.canRestartSelection(currentAttributeId, currentAttributeValue);
		 		
		 		if(restartSelection){
		 			options.scope.selectedVariationAttributes = {};
		 			options.scope.selectedVariationAttributes[currentAttributeId] = currentAttributeValue;
		 			variationItemUtils.initializeUI();
		 		}else{
        			options.scope.selectedVariationAttributes[currentAttributeId] = currentAttributeValue;
		 		}
        		
        		var validAttributes = variationItemUtils.getValidAttributeValues(options.scope.selectedVariationAttributes, currentAttributeId);
        		variationItemUtils.updateUIValidAttributeValues(validAttributes, currentAttributeId, currentAttributeValue, restartSelection);
        		
        		//Disable all the invalid attributes
        		var invalidAttributes = variationItemUtils.getInvalidAttributeValues(validAttributes, currentAttributeId);
        		variationItemUtils.updateUIInvalidAttributeValues(invalidAttributes, currentAttributeId, currentAttributeValue, options.scope.selectedVariationAttributes, restartSelection);
        		
        		variationItemUtils.updateSelectedItem(options.scope.selectedVariationAttributes, options.scope.Currency);
        		
        		this.doLayout();
		    	this.syncSize();
		    	sc.sfs.util.containerUtil.refreshContainer();
	 			return true;
	 		}else if(target.id === "add_to_quote"){
			 	var item = sc.sfs.itembrowsing.ItemUtils.getDOMAttribute(target, "iteminfo");
			 	sc.sfs.itembrowsing.ItemUtils.addToQuoteItems(Ext.decode(item));
			 	return true;
			 }
		 }
		 return false;
    },
    
    getHelpId:function(){
    	return "SFSITM00002";
	},
    
    getBackButtonText: function(){
    	return String.format(this.b_Back_To_Lbl, this.itemDetails.Item.ItemID);
    }
    
});
Ext.reg('itemdetails', sc.sfs.itembrowsing.ItemDetails);
